@@ -34,15 +34,15 @@
 #include <tqglobal.h>
 
 #include <kurldrag.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kimageio.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
+#include <tdeio/netaccess.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 #include <kcombobox.h>
 #include <kcolorbutton.h>
 #include <kpushbutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include <cstdlib>
 #include <fstream>
@@ -105,7 +105,7 @@ MainWidget::~MainWidget() {
 }
 
 void MainWidget::fileOpen() {
-  KFileDialog d(TQString(),KImageIO::pattern(),this,i18n("Select an image"),true);
+  KFileDialog d(TQString(),KImageIO::pattern(),this,i18n("Select an image").utf8(),true);
   d.exec();
 
   if(d.result()==TQDialog::Accepted)
@@ -158,11 +158,11 @@ void MainWidget::fileSave() {
     if(salva)
     {
       m_outputFilename=saveFilename;
-      ifstream in(m_tmpFilename);
-      ofstream out(m_outputFilename);
+      ifstream in(m_tmpFilename.local8Bit());
+      ofstream out(m_outputFilename.local8Bit());
       if(!in || !out)
       {
-        emit signalChangeStatusbar(i18n(i18n("Error while saving file")));
+        emit signalChangeStatusbar(i18n("Error while saving file"));
         return;
       }
       emit signalChangeStatusbar(i18n("Saving %1...").arg(m_outputFilename));
@@ -179,8 +179,8 @@ void MainWidget::fileSave() {
   }
   else if (m_changed)
   {
-    ifstream in(m_tmpFilename);
-    ofstream out(m_outputFilename);
+    ifstream in(m_tmpFilename.local8Bit());
+    ofstream out(m_outputFilename.local8Bit());
     if(!in || !out)
     {
       emit signalChangeStatusbar(i18n("Error while saving file"));
@@ -244,8 +244,8 @@ void MainWidget::fileSaveAs() {
     if(salva)
     {
       m_outputFilename=saveFilename;
-      ifstream in(m_tmpFilename);
-      ofstream out(m_outputFilename);
+      ifstream in(m_tmpFilename.local8Bit());
+      ofstream out(m_outputFilename.local8Bit());
       if(!in || !out)
       {
         emit signalChangeStatusbar(i18n("Error while saving file"));
@@ -345,7 +345,7 @@ void MainWidget::getImageFromURL(KURL url) {
   TQString filename;				// prevent overwriting previous local file with current remote one
   if (!url.isLocalFile())
   {           // download to temporary file
-    if (!KIO::NetAccess::download(url,filename,this))
+    if (!TDEIO::NetAccess::download(url,filename,this))
       emit signalChangeStatusbar(i18n("Selected URL is not a valid image."));
     return;
   }
@@ -369,7 +369,7 @@ void MainWidget::getImageFromURL(KURL url) {
   emit signalChangeStatusbar(i18n("File %1 loaded.").arg(filename));
 
   if (!url.isLocalFile())
-    KIO::NetAccess::removeTempFile(filename);
+    TDEIO::NetAccess::removeTempFile(filename);
 
   Options *o=new Options();
   if (!preserveCheck->isChecked())
@@ -827,7 +827,7 @@ TQStringList MainWidget::createAutotraceCommandLine( ) {
 	toReturn+="--input-format=PPM";
 	toReturn+=m_tmpInputFilename;
 		
-	qDebug("Executed:\n%s",toReturn.join(" ").ascii());
+	tqDebug("Executed:\n%s",toReturn.join(" ").ascii());
 	
 	return toReturn;
 }
@@ -919,7 +919,7 @@ void MainWidget::tracerExited() {
     else
     {
       emit(signalChangeStatusbar(i18n("Output format not recognized")));
-      previewLabel->setText(i18n("Sorry, but the image format which you are working with\nis not recognized by KDE.\nThe image will be correctly saved if you want to,\nbut to see a preview try working with another image format (EPS and PGM showld work well)\nand only when you are satisfied with the result revert to the format\nof your choiche and save the result."));
+      previewLabel->setText(i18n("Sorry, but the image format which you are working with\nis not recognized by TDE.\nThe image will be correctly saved if you want to,\nbut to see a preview try working with another image format (EPS and PGM showld work well)\nand only when you are satisfied with the result revert to the format\nof your choiche and save the result."));
       imagesTabs->setCurrentPage(1);
       setCursor(ArrowCursor);
       return;
